import { Geography } from '../../../domain/entities/geography';

describe('Geography entity', () => {
  it('should be defined', () => {
    const geography = new Geography(
      {
        waypoints: [
          {
            lat: 49.440041,
            lon: 1.093912,
          },
          {
            lat: 50.630992,
            lon: 3.045432,
          },
        ],
      },
      'Europe/Paris',
    );
    expect(geography).toBeDefined();
  });

  describe('init', () => {
    it('should initialize a geography request', () => {
      const geography = new Geography(
        {
          waypoints: [
            {
              lat: 49.440041,
              lon: 1.093912,
            },
            {
              lat: 50.630992,
              lon: 3.045432,
            },
          ],
        },
        'Europe/Paris',
      );
      geography.init();
      expect(geography.waypoints.length).toBe(2);
    });
    it('should throw an exception if waypoints are empty', () => {
      const geography = new Geography(
        {
          waypoints: [],
        },
        'Europe/Paris',
      );
      expect(() => geography.init()).toThrow();
    });
    it('should throw an exception if only one waypoint is provided', () => {
      const geography = new Geography(
        {
          waypoints: [
            {
              lat: 49.440041,
              lon: 1.093912,
            },
          ],
        },
        'Europe/Paris',
      );
      expect(() => geography.init()).toThrow();
    });
    it('should throw an exception if a waypoint has invalid longitude', () => {
      const geography = new Geography(
        {
          waypoints: [
            {
              lat: 49.440041,
              lon: 201.093912,
            },
            {
              lat: 50.630992,
              lon: 3.045432,
            },
          ],
        },
        'Europe/Paris',
      );
      expect(() => geography.init()).toThrow();
    });
    it('should throw an exception if a waypoint has invalid latitude', () => {
      const geography = new Geography(
        {
          waypoints: [
            {
              lat: 49.440041,
              lon: 1.093912,
            },
            {
              lat: 250.630992,
              lon: 3.045432,
            },
          ],
        },
        'Europe/Paris',
      );
      expect(() => geography.init()).toThrow();
    });
  });
});
