import { Route } from '../../../domain/entities/route';
import { SpacetimePoint } from '../../../domain/entities/spacetime-point';
import { Waypoint } from '../../../domain/entities/waypoint';

const mockGeodesic = {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  inverse: jest.fn().mockImplementation((lon1, lat1, lon2, lat2) => {
    return lon1 == 0
      ? {
          azimuth: 45,
          distance: 50000,
        }
      : {
          azimuth: -45,
          distance: 60000,
        };
  }),
};

describe('Route entity', () => {
  it('should be defined', () => {
    const route = new Route(mockGeodesic);
    expect(route).toBeDefined();
  });
  it('should set waypoints and geodesic values for a route', () => {
    const route = new Route(mockGeodesic);
    const waypoint1: Waypoint = new Waypoint();
    waypoint1.point = [0, 0];
    const waypoint2: Waypoint = new Waypoint();
    waypoint2.point = [10, 10];
    route.setWaypoints([waypoint1, waypoint2]);
    expect(route.waypoints.length).toBe(2);
    expect(route.fwdAzimuth).toBe(45);
    expect(route.backAzimuth).toBe(225);
    expect(route.distanceAzimuth).toBe(50000);
  });
  it('should set points and geodesic values for a route', () => {
    const route = new Route(mockGeodesic);
    route.setPoints([
      [10, 10],
      [20, 20],
    ]);
    expect(route.points.length).toBe(2);
    expect(route.fwdAzimuth).toBe(315);
    expect(route.backAzimuth).toBe(135);
    expect(route.distanceAzimuth).toBe(60000);
  });
  it('should set spacetimePoints for a route', () => {
    const route = new Route(mockGeodesic);
    const spacetimePoint1 = new SpacetimePoint([0, 0], 0, 0);
    const spacetimePoint2 = new SpacetimePoint([10, 10], 500, 5000);
    route.setSpacetimePoints([spacetimePoint1, spacetimePoint2]);
    expect(route.spacetimePoints.length).toBe(2);
  });
});
